#include "Seeed_BME280.h" // Including libraries
#include "rgb_lcd.h" // Including the library for LCD
#include <Wire.h>

float temp; //Create variables to store values
float p;
int H;

int dust_output;
float dust_voltage;
float dust;

int LED=7; //Dust and LED pin numbers
int DUSTpin=0;

int colorR[] = {0,0,0,255,255,255};
int colorG[] = {128,255,255,255,170,0};
int colorB[] = {255,255,0,0,0,0};

BME280 bme280; //Create object of BME280 class
rgb_lcd lcd; //Create object of rgb_lcd class

void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600); 
  if(!bme280.init()) Serial.println("Error with connection!");

  //Change reference voltage from 5V to 1.1V
  analogReference(INTERNAL1V1);
  pinMode(LED,OUTPUT);
  digitalWrite(LED,LOW); //Set 0V to LED pin
   
  //Define size of LCD and colors
  lcd.begin(16,2);

  Serial.println("T (C) \t p (Pa) \t H (%) \t Dust (ug/m3)");

}

float getDust()
{
  
  float averageDust=0.0;

  for(int i=0; i<10; i++)
  {
    //Measure dust
    digitalWrite(LED,HIGH);
    delayMicroseconds(280);
    dust_output=analogRead(DUSTpin);
    digitalWrite(LED,LOW);

    //Calculate voltage
    //Multiply voltage by 11 because voltage divider was used
    dust_voltage = (1100.0/1024.0)*dust_output*11;
    //Calculate dust when voltage is higher than minimal
    if(dust_voltage>600) averageDust+=(dust_voltage-600)*0.2; 
    delay(500);
  }

  return (averageDust/10.0);
}

void loop() {
  // put your main code here, to run repeatedly:
  //Read temperature value and print to serial port
  temp=bme280.getTemperature();
  Serial.print(temp);
  Serial.print("\t");
  //Read pressure value and print to serial port
  p=bme280.getPressure()/100.0;
  Serial.print(p);
  Serial.print("\t");
  //Read humidity value and print to serial port
  H=bme280.getHumidity();
  Serial.print(H);
  Serial.print("\t");

  dust = getDust();
  Serial.println(dust);

  if(temp<0) lcd.setRGB(colorR[0], colorG[0], colorB[0]);
  if(temp>0 && temp<5) lcd.setRGB(colorR[1], colorG[1], colorB[1]);
  if(temp>5 && temp<15) lcd.setRGB(colorR[2], colorG[2], colorB[2]);
  if(temp>15 && temp<25) lcd.setRGB(colorR[3], colorG[3], colorB[3]);
  if(temp>25 && temp<30) lcd.setRGB(colorR[4], colorG[4], colorB[4]);
  if(temp>30) lcd.setRGB(colorR[5], colorG[5], colorB[5]);
  lcd.setCursor(0,0);
  lcd.print(temp);
  lcd.print("C ");
  lcd.print(dust);
  lcd.print("ug/m3");
  lcd.setCursor(0,1);
  lcd.print("");
  lcd.print(p);
  lcd.print("hPa ");
  lcd.print(H);
  lcd.print("%");
  
  delay(1000);
}
